# osparcAPIcontrol



***

## Name
osparcAPIcontrol

## Description
providing a variety of tools to interact with osparc API faster. <br /> 
Compiles the different functionalities of the osparc package into composites to simplify and speed up its usage. 
## Badges
[![PyPI](https://img.shields.io/pypi/v/osparcAPIcontrol)](https://pypi.org/project/osparcAPIcontrol/)
[![](https://img.shields.io/pypi/status/osparcAPIcontrol)](https://pypi.org/project/osparcAPIcontrol/)
[![](https://img.shields.io/pypi/l/osparcAPIcontrol )](https://pypi.org/project/osparcAPIcontrol/)
## Installation
```bash
pip install osparcAPIcontrol
```
## Usage
```python
import pprint
from osparcAPIcontrol.controller import OsparcAPIcontroller

# to instantiate a controller object, pass host, your username and password. 
# hosts:
# "https://api.osparc.io" for osparc.io
# "https://api.osparc.speag.com" for s4l.speag.com
#
#username and password can be acquired by creating an API Token on the respective website.
username = 'some_string'
password = 'some_other_string'

control = OsparcAPIcontroller(host="https://api.osparc.io",
                              username=username,
                              password=password)

# prints a list of all available solvers and their properties
control.print_solvers()

# choose a set of solvers to use in your workflow which are saved in a dictionary
control.initialize_solvers(solver_list=['isolve-mpi', 's4l Python Runner'])
print('\n')
pprint.pprint(control.solvers_in_use)
print('\n')
print(control.solvers_in_use['isolve-mpi'])
```
## Support
msteiner@itis.swiss

## Roadmap
1. More functions to interact with the API will be added
2. Existing functions will be further unified/combined
3. Functionalities to easily store and access the metadata files containing important file IDs

## Authors and acknowledgment
pcrespov, main author of the osparc package

## License
[MIT](https://choosealicense.com/licenses/mit/)

